@@ -1565,8 +1565,6 @@ def modify_alarm(speaker, action, args, soco_function, use_local_speaker_list):
             error_and_exit("Failed to modify alarm")
             return False
 
-        print("Alarm ID '{}' modified".format(alarm._alarm_id))
-
     return True
 
 
@@ -1604,6 +1602,9 @@ def move_or_copy_alarm(speaker, alarm_id, copy=True):
         error_and_exit("Failed to copy/move alarm")
         return False
 
+    if copy is True:
+        print("Alarm ID '{}' created".format(alarm._alarm_id))
+
     return True
 
 
@@ -2813,6 +2814,6 @@ actions = {
     "disable_alarms": SonosFunction(disable_alarms, "", False),
     "modify_alarm": SonosFunction(modify_alarm, "", False),
     "modify_alarms": SonosFunction(modify_alarm, "", False),
-    "copy_alarm":  SonosFunction(copy_alarm, "", False),
-    "move_alarm":  SonosFunction(move_alarm, "", False),
+    "copy_alarm": SonosFunction(copy_alarm, "", False),
+    "move_alarm": SonosFunction(move_alarm, "", False),
 }
